Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the aws v1alpha1 API group +kubebuilder:object:generate=true +groupName=aws.90poe.io
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "aws.90poe.io", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type GlueJob ¶
type GlueJob struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec GlueJobSpec `json:"spec,omitempty"`
Status GlueJobStatus `json:"status,omitempty"`
}
GlueJob is the Schema for the gluejobs API
func (*GlueJob) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GlueJob.
func (*GlueJob) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GlueJob) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GlueJobCommand ¶
type GlueJobCommand struct {
// +required
// +kubebuilder:validation:Required
// +kubebuilder:validation:MaxLength=1024
// +kubebuilder:validation:MinLength=1
Name string `json:"name"`
// +kubebuilder:default=3
// +kubebuilder:validation:Format=`^(2|3)$`
PythonVersion int `json:"pythonVersion,omitempty"`
// +kubebuilder:default=glueetl
Runtime string `json:"runtime,omitempty"`
// +required
// +kubebuilder:validation:Required
// +kubebuilder:validation:MaxLength=1024
// +kubebuilder:validation:MinLength=10
// +kubebuilder:validation:Format=`^s3://.+\/.+$`
ScriptLocation string `json:"scriptLocation"`
}
https://pkg.go.dev/github.com/aws/aws-sdk-go-v2/service/glue@v1.63.0/types#JobCommand
func (*GlueJobCommand) DeepCopy ¶
func (in *GlueJobCommand) DeepCopy() *GlueJobCommand
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GlueJobCommand.
func (*GlueJobCommand) DeepCopyInto ¶
func (in *GlueJobCommand) DeepCopyInto(out *GlueJobCommand)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GlueJobExecutionProperty ¶
type GlueJobExecutionProperty struct {
// +kubebuilder:default=1
MaxConcurrentRuns int32 `json:"maxConcurrentRuns,omitempty"`
}
func (*GlueJobExecutionProperty) DeepCopy ¶
func (in *GlueJobExecutionProperty) DeepCopy() *GlueJobExecutionProperty
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GlueJobExecutionProperty.
func (*GlueJobExecutionProperty) DeepCopyInto ¶
func (in *GlueJobExecutionProperty) DeepCopyInto(out *GlueJobExecutionProperty)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GlueJobList ¶
type GlueJobList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []GlueJob `json:"items"`
}
GlueJobList contains a list of GlueJob
func (*GlueJobList) DeepCopy ¶
func (in *GlueJobList) DeepCopy() *GlueJobList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GlueJobList.
func (*GlueJobList) DeepCopyInto ¶
func (in *GlueJobList) DeepCopyInto(out *GlueJobList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GlueJobList) DeepCopyObject ¶
func (in *GlueJobList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GlueJobSpec ¶
type GlueJobSpec struct {
// Name is the name of the Glue Job
// +required
// +kubebuilder:validation:Required
// +kubebuilder:validation:MaxLength=1024
// +kubebuilder:validation:MinLength=10
Name string `json:"name"`
// Command is the Glue Job Command https://pkg.go.dev/github.com/aws/aws-sdk-go-v2/service/glue@v1.63.0/types#JobCommand
// +required
// +kubebuilder:validation:Required
Command GlueJobCommand `json:"command"`
// Role is the IAM role to be used by the Glue Job
// +required
// +kubebuilder:validation:Required
// +kubebuilder:validation:MaxLength=1024
// +kubebuilder:validation:MinLength=28
// +kubebuilder:validation:Format=`^arn:aws:iam::.*:role\/.*$`
Role string `json:"role"`
// Timeout is the timeout in minutes for the Glue Job, max 2 days
// +kubebuilder:default=20
// +kubebuilder:validation:Maximum=2880
TimeoutInMinutes int32 `json:"timeout,omitempty"`
// GlueVersion is the version of Glue to be used by the Glue Job
// +kubebuilder:default="4.0"
GlueVersion string `json:"glueVersion,omitempty"`
// NumberOfWorkers is the number of workers to be used by the Glue Job
// +kubebuilder:default=2
NumberOfWorkers int32 `json:"numberOfWorkers,omitempty"`
// WorkerType is the type of worker to be used by the Glue Job
// +kubebuilder:default=G.1X
WorkerType string `json:"workerType,omitempty"`
// ExecutionProperty is the execution property to be used by the Glue Job
// +kubebuilder:default=FLEX
// +kubebuilder:validation:Format=`^(FLEX|STANDARD)$`
ExecutionClass string `json:"executionClass,omitempty"`
// ExecutionProperty is the execution property to be used by the Glue Job
// +kubebuilder:default={maxConcurrentRuns: 1}
ExecutionProperty *GlueJobExecutionProperty `json:"executionProperty,omitempty"`
// MaxRetries is the max number of retries to be used by the Glue Job
// +kubebuilder:default=0
MaxRetries int32 `json:"maxRetries,omitempty"`
// DefaultArguments is the default arguments to be used by the Glue Job
DefaultArguments map[string]string `json:"defaultArguments,omitempty"`
// Tags is the tags to be set on the Glue Job
Tags map[string]string `json:"tags,omitempty"`
}
GlueJobSpec defines the desired state of GlueJob
func (*GlueJobSpec) DeepCopy ¶
func (in *GlueJobSpec) DeepCopy() *GlueJobSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GlueJobSpec.
func (*GlueJobSpec) DeepCopyInto ¶
func (in *GlueJobSpec) DeepCopyInto(out *GlueJobSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GlueJobStatus ¶
type GlueJobStatus struct {
// Conditions store the status conditions of the GlueJob instances
// +operator-sdk:csv:customresourcedefinitions:type=status
Conditions []metav1.Condition `json:"conditions,omitempty" patchStrategy:"merge" patchMergeKey:"type" protobuf:"bytes,1,rep,name=conditions"`
}
GlueJobStatus defines the observed state of GlueJob
func (*GlueJobStatus) DeepCopy ¶
func (in *GlueJobStatus) DeepCopy() *GlueJobStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GlueJobStatus.
func (*GlueJobStatus) DeepCopyInto ¶
func (in *GlueJobStatus) DeepCopyInto(out *GlueJobStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.